#!/bin/sh

#
# Copyright (C) 2012-2019 Oracle Corporation
#
# This file is part of VirtualBox Open Source Edition (OSE), as
# available from http://www.virtualbox.org. This file is free software;
# you can redistribute it and/or modify it under the terms of the GNU
# General Public License (GPL) as published by the Free Software
# Foundation, in version 2 as it comes in the "COPYING" file of the
# VirtualBox OSE distribution. VirtualBox OSE is distributed in the
# hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
#

#
# Wrapper for the per user autostart daemon. Gets a list of all users
# and starts the VMs.
#

RUNASUSER="/Library/Application Support/VBoxStartAtBoot/runasuser"
VBOXMANAGE="/Applications/VirtualBox.app/Contents/MacOS/VBoxManage"
VBOXAUTOSTART="/Applications/VirtualBox.app/Contents/MacOS/VBoxAutostart"
MAXWAIT=60

function vboxStartStopAllUserVms()
{
    # Go through the list and filter out all users without a shell and a
    # non existing home.

	count=0
    while [ $count -lt $MAXWAIT ]; do
		count=$((count+1))
		"${VBOXMANAGE}" list vms >/dev/null 2>&1
		rc=$?
		if [ $rc -eq 0 ]; then
			break
		fi
		echo "Waiting for VirtualBox: $count"
		sleep 1
    done

	count=0
	vmvolumes="/Library/Application Support/VBoxStartAtBoot/vmvolumes"
    while [ $count -lt $MAXWAIT ]; do
		count=$((count+1))
		nvolumes=0
		nexist=0
		while IFS= read -r volume
		do
			echo "Looking for volume: ${volume}"
			nvolumes=$((nvolumes+1))
			$(/sbin/mount|/usr/bin/grep "${volume}" >/dev/null 2>&1)
			rc=$?
			if [ $rc -eq 0 ]; then
				echo "Found volume: ${volume}"
				nexist=$((nexist+1))
			fi
		done < "${vmvolumes}"

		if [ $nvolumes -eq $nexist ]; then
			break
		fi
		echo "Waiting for VM volumes to be mounted"
		sleep 1
    done

    for user in `dscl . -list /Users`
    do
        HOMEDIR=`dscl . -read /Users/${user} | grep NFSHomeDirectory | sed 's/NFSHomeDirectory: //g'`
        USERSHELL=`dscl . -read /Users/${user} | grep UserShell | sed 's/UserShell: //g'`

        # Check for known home directories and shells for daemons
        if [[   "${HOMEDIR}" == "/var/empty" || "${HOMEDIR}" == "/dev/null" || "${HOMEDIR}" == "/var/root"
             || "${USERSHELL}" == "/usr/bin/false" || "${USERSHELL}" == "/dev/null" || "${USERSHELL}" == "/usr/sbin/uucico" ]]
        then
            continue
        fi

        case "${1}" in
            start)
                # Start the daemon
                echo "Starting VMs for: ${user}"
                ##"${RUNASUSER}" ${user} "/Applications/VirtualBox.app/Contents/MacOS/VBoxAutostart --quiet --start --background --config ${CONFIG}"
                "${RUNASUSER}" ${user} "${VBOXAUTOSTART} --verbose --start --background --config ${CONFIG}"
                ;;
            stop)
                # Start the daemon
                ##"${RUNASUSER}" ${user} "/Applications/VirtualBox.app/Contents/MacOS/VBoxAutostart --quiet --stop --config ${CONFIG}"
                "${RUNASUSER}" ${user} "${VBOXAUTOSTART} --verbose --stop --config ${CONFIG}"
                ;;
               *)
                echo "Usage: start|stop"
                exit 1
        esac
    done
}

function vboxStopAllUserVms()
{
    vboxStartStopAllUserVms "stop"
}

CONFIG=${1}
vboxStartStopAllUserVms "start"
trap vboxStopAllUserVms HUP KILL TERM

